@@ -52,7 +52,7 @@ def pytest_configure(config):
     if not config.getoption('installed'):
         pyfuse3_path = os.path.join(basedir, 'src')
         if (os.path.exists(os.path.join(basedir, 'setup.py')) and
-            os.path.exists(os.path.join(basedir, 'src', 'pyfuse3.pyx'))):
+            os.path.exists(os.path.join(basedir, 'src', 'pyfuse3', '__init__.pyx'))):
             sys.path.insert(0, pyfuse3_path)
 
         # Make sure that called processes use the same path
